diff --git a/core/modules/aggregator/lib/Drupal/aggregator/Plugin/views/field/Category.php b/core/modules/aggregator/lib/Drupal/aggregator/Plugin/views/field/Category.php
index 589a166..e42c0ca 100644
--- a/core/modules/aggregator/lib/Drupal/aggregator/Plugin/views/field/Category.php
+++ b/core/modules/aggregator/lib/Drupal/aggregator/Plugin/views/field/Category.php
@@ -77,7 +77,7 @@ protected function renderLink($data, ResultRow $values) {
   /**
    * {@inheritdoc}
    */
-  public function render($values) {
+  public function render(ResultRow $values) {
     $value = $this->getValue($values);
     return $this->renderLink($this->sanitizeValue($value), $values);
   }
diff --git a/core/modules/aggregator/lib/Drupal/aggregator/Plugin/views/field/TitleLink.php b/core/modules/aggregator/lib/Drupal/aggregator/Plugin/views/field/TitleLink.php
index 74aeb03..b8d8508 100644
--- a/core/modules/aggregator/lib/Drupal/aggregator/Plugin/views/field/TitleLink.php
+++ b/core/modules/aggregator/lib/Drupal/aggregator/Plugin/views/field/TitleLink.php
@@ -58,7 +58,7 @@ public function buildOptionsForm(&$form, &$form_state) {
   /**
    * {@inheritdoc}
    */
-  public function render($values) {
+  public function render(ResultRow $values) {
     $value = $this->getValue($values);
     return $this->renderLink($this->sanitizeValue($value), $values);
   }
diff --git a/core/modules/comment/lib/Drupal/comment/Plugin/views/field/Comment.php b/core/modules/comment/lib/Drupal/comment/Plugin/views/field/Comment.php
index 46e6e28..1fd7050 100644
--- a/core/modules/comment/lib/Drupal/comment/Plugin/views/field/Comment.php
+++ b/core/modules/comment/lib/Drupal/comment/Plugin/views/field/Comment.php
@@ -80,7 +80,10 @@ protected function renderLink($data, ResultRow $values) {
     return $data;
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     $value = $this->getValue($values);
     return $this->renderLink($this->sanitizeValue($value), $values);
   }
diff --git a/core/modules/comment/lib/Drupal/comment/Plugin/views/field/Depth.php b/core/modules/comment/lib/Drupal/comment/Plugin/views/field/Depth.php
index 2076ff8..58f97c7 100644
--- a/core/modules/comment/lib/Drupal/comment/Plugin/views/field/Depth.php
+++ b/core/modules/comment/lib/Drupal/comment/Plugin/views/field/Depth.php
@@ -9,6 +9,7 @@
 
 use Drupal\Component\Annotation\PluginID;
 use Drupal\views\Plugin\views\field\FieldPluginBase;
+use Drupal\views\ResultRow;
 
 /**
  * Field handler to display the depth of a comment.
@@ -20,9 +21,9 @@
 class Depth extends FieldPluginBase {
 
   /**
-   * Work out the depth of this comment
+   * {@inheritdoc}
    */
-  public function render($values) {
+  public function render(ResultRow $values) {
     $comment_thread = $this->getValue($values);
     return count(explode('.', $comment_thread)) - 1;
   }
diff --git a/core/modules/comment/lib/Drupal/comment/Plugin/views/field/LastTimestamp.php b/core/modules/comment/lib/Drupal/comment/Plugin/views/field/LastTimestamp.php
index ee2772b..5ba79da 100644
--- a/core/modules/comment/lib/Drupal/comment/Plugin/views/field/LastTimestamp.php
+++ b/core/modules/comment/lib/Drupal/comment/Plugin/views/field/LastTimestamp.php
@@ -9,6 +9,7 @@
 
 use Drupal\views\Plugin\views\field\Date;
 use Drupal\views\Plugin\views\display\DisplayPluginBase;
+use Drupal\views\ResultRow;
 use Drupal\views\ViewExecutable;
 use Drupal\Component\Annotation\PluginID;
 
@@ -30,7 +31,10 @@ public function init(ViewExecutable $view, DisplayPluginBase $display, array &$o
     $this->additional_fields['comment_count'] = 'comment_count';
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     $comment_count = $this->getValue($values, 'comment_count');
     if (empty($this->options['empty_zero']) || $comment_count) {
       return parent::render($values);
diff --git a/core/modules/comment/lib/Drupal/comment/Plugin/views/field/Link.php b/core/modules/comment/lib/Drupal/comment/Plugin/views/field/Link.php
index bbfd55f..3c6ba13 100644
--- a/core/modules/comment/lib/Drupal/comment/Plugin/views/field/Link.php
+++ b/core/modules/comment/lib/Drupal/comment/Plugin/views/field/Link.php
@@ -43,7 +43,10 @@ public function buildOptionsForm(&$form, &$form_state) {
 
   public function query() {}
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     $comment = $this->getEntity($values);
     return $this->renderLink($comment, $values);
   }
diff --git a/core/modules/comment/lib/Drupal/comment/Plugin/views/field/NcsLastCommentName.php b/core/modules/comment/lib/Drupal/comment/Plugin/views/field/NcsLastCommentName.php
index 6be3577..600eb97 100644
--- a/core/modules/comment/lib/Drupal/comment/Plugin/views/field/NcsLastCommentName.php
+++ b/core/modules/comment/lib/Drupal/comment/Plugin/views/field/NcsLastCommentName.php
@@ -9,6 +9,7 @@
 
 use Drupal\views\Plugin\views\field\FieldPluginBase;
 use Drupal\Component\Annotation\PluginID;
+use Drupal\views\ResultRow;
 
 /**
  * Field handler to present the name of the last comment poster.
@@ -56,7 +57,10 @@ protected function defineOptions() {
     return $options;
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     if (!empty($this->options['link_to_user'])) {
       $account = entity_create('user', array());
       $account->name = $this->getValue($values);
diff --git a/core/modules/comment/lib/Drupal/comment/Plugin/views/field/NodeComment.php b/core/modules/comment/lib/Drupal/comment/Plugin/views/field/NodeComment.php
index 6642db7..3beb7e2 100644
--- a/core/modules/comment/lib/Drupal/comment/Plugin/views/field/NodeComment.php
+++ b/core/modules/comment/lib/Drupal/comment/Plugin/views/field/NodeComment.php
@@ -9,6 +9,7 @@
 
 use Drupal\views\Plugin\views\field\FieldPluginBase;
 use Drupal\Component\Annotation\PluginID;
+use Drupal\views\ResultRow;
 
 /**
  * Display node comment status.
@@ -19,7 +20,10 @@
  */
 class NodeComment extends FieldPluginBase {
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     $value = $this->getValue($values);
     switch ($value) {
       case COMMENT_NODE_HIDDEN:
diff --git a/core/modules/comment/lib/Drupal/comment/Plugin/views/field/NodeLink.php b/core/modules/comment/lib/Drupal/comment/Plugin/views/field/NodeLink.php
index 08ec430..d824118 100644
--- a/core/modules/comment/lib/Drupal/comment/Plugin/views/field/NodeLink.php
+++ b/core/modules/comment/lib/Drupal/comment/Plugin/views/field/NodeLink.php
@@ -9,6 +9,7 @@
 
 use Drupal\views\Plugin\views\field\FieldPluginBase;
 use Drupal\Component\Annotation\PluginID;
+use Drupal\views\ResultRow;
 
 /**
  * Handler for showing comment module's node link.
@@ -38,7 +39,10 @@ public function buildOptionsForm(&$form, &$form_state) {
 
   public function query() {}
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     $node = $this->getEntity($values);
     comment_node_view($node, $this->options['teaser'] ? 'teaser' : 'full');
 
diff --git a/core/modules/comment/lib/Drupal/comment/Plugin/views/field/NodeNewComments.php b/core/modules/comment/lib/Drupal/comment/Plugin/views/field/NodeNewComments.php
index acef5a7..6da4cb1 100644
--- a/core/modules/comment/lib/Drupal/comment/Plugin/views/field/NodeNewComments.php
+++ b/core/modules/comment/lib/Drupal/comment/Plugin/views/field/NodeNewComments.php
@@ -143,7 +143,10 @@ protected function renderLink($data, ResultRow $values) {
     return $data;
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     $value = $this->getValue($values);
     if (!empty($value)) {
       return $this->renderLink(parent::render($values), $values);
diff --git a/core/modules/comment/lib/Drupal/comment/Plugin/views/field/Username.php b/core/modules/comment/lib/Drupal/comment/Plugin/views/field/Username.php
index d969236..fc8275c 100644
--- a/core/modules/comment/lib/Drupal/comment/Plugin/views/field/Username.php
+++ b/core/modules/comment/lib/Drupal/comment/Plugin/views/field/Username.php
@@ -66,7 +66,10 @@ protected function renderLink($data, ResultRow $values) {
     }
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     $value = $this->getValue($values);
     return $this->renderLink($this->sanitizeValue($value), $values);
   }
diff --git a/core/modules/content_translation/lib/Drupal/content_translation/Plugin/views/field/TranslationLink.php b/core/modules/content_translation/lib/Drupal/content_translation/Plugin/views/field/TranslationLink.php
index 20c894e..474e543 100644
--- a/core/modules/content_translation/lib/Drupal/content_translation/Plugin/views/field/TranslationLink.php
+++ b/core/modules/content_translation/lib/Drupal/content_translation/Plugin/views/field/TranslationLink.php
@@ -43,9 +43,9 @@ public function buildOptionsForm(&$form, &$form_state) {
   }
 
   /**
-   * Overrides \Drupal\views\Plugin\views\field\FieldPluginBase::render().
+   * {@inheritdoc}
    */
-  public function render($values) {
+  public function render(ResultRow $values) {
     return $this->renderLink($this->getEntity($values), $values);
   }
 
diff --git a/core/modules/contextual/lib/Drupal/contextual/Plugin/views/field/ContextualLinks.php b/core/modules/contextual/lib/Drupal/contextual/Plugin/views/field/ContextualLinks.php
index bc4a34d..04824a3 100644
--- a/core/modules/contextual/lib/Drupal/contextual/Plugin/views/field/ContextualLinks.php
+++ b/core/modules/contextual/lib/Drupal/contextual/Plugin/views/field/ContextualLinks.php
@@ -9,6 +9,7 @@
 
 use Drupal\Component\Annotation\PluginID;
 use Drupal\views\Plugin\views\field\FieldPluginBase;
+use Drupal\views\ResultRow;
 
 /**
  * Provides a handler that adds contextual links.
@@ -63,12 +64,12 @@ public function preRender(&$values) {
   }
 
   /**
-   * Render the contextual fields.
+   * Overrides \Drupal\views\Plugin\views\field\FieldPluginBase::render().
    *
    * @see contextual_preprocess()
    * @see contextual_contextual_links_view_alter()
    */
-  public function render($values) {
+  public function render(ResultRow $values) {
     $links = array();
     foreach ($this->options['fields'] as $field) {
       $rendered_field = $this->view->style_plugin->getField($this->view->row_index, $field);
diff --git a/core/modules/file/lib/Drupal/file/Plugin/views/field/Extension.php b/core/modules/file/lib/Drupal/file/Plugin/views/field/Extension.php
index ff98cfd..add942f 100644
--- a/core/modules/file/lib/Drupal/file/Plugin/views/field/Extension.php
+++ b/core/modules/file/lib/Drupal/file/Plugin/views/field/Extension.php
@@ -9,6 +9,7 @@
 
 use Drupal\Component\Annotation\PluginID;
 use Drupal\views\Plugin\views\field\FieldPluginBase;
+use Drupal\views\ResultRow;
 
 /**
  * Returns a pure file extension of the file, for example 'module'.
@@ -41,7 +42,10 @@ public function buildOptionsForm(&$form, &$form_state) {
     );
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     $value = $this->getValue($values);
     if (!$this->options['extension_detect_tar']) {
       if (preg_match('/\.([^\.]+)$/', $value, $match)) {
diff --git a/core/modules/file/lib/Drupal/file/Plugin/views/field/File.php b/core/modules/file/lib/Drupal/file/Plugin/views/field/File.php
index bc492e2..df5056f 100644
--- a/core/modules/file/lib/Drupal/file/Plugin/views/field/File.php
+++ b/core/modules/file/lib/Drupal/file/Plugin/views/field/File.php
@@ -66,7 +66,10 @@ protected function renderLink($data, ResultRow $values) {
     return $data;
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     $value = $this->getValue($values);
     return $this->renderLink($this->sanitizeValue($value), $values);
   }
diff --git a/core/modules/file/lib/Drupal/file/Plugin/views/field/FileMime.php b/core/modules/file/lib/Drupal/file/Plugin/views/field/FileMime.php
index 1756460..8c6ab7e 100644
--- a/core/modules/file/lib/Drupal/file/Plugin/views/field/FileMime.php
+++ b/core/modules/file/lib/Drupal/file/Plugin/views/field/FileMime.php
@@ -8,6 +8,7 @@
 namespace Drupal\file\Plugin\views\field;
 
 use Drupal\Component\Annotation\PluginID;
+use Drupal\views\ResultRow;
 
 /**
  * Field handler to add rendering MIME type images as an option on the filemime field.
@@ -33,7 +34,10 @@ public function buildOptionsForm(&$form, &$form_state) {
     parent::buildOptionsForm($form, $form_state);
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     $data = $values->{$this->field_alias};
     if (!empty($this->options['filemime_image']) && $data !== NULL && $data !== '') {
       $file_icon = array(
diff --git a/core/modules/file/lib/Drupal/file/Plugin/views/field/Status.php b/core/modules/file/lib/Drupal/file/Plugin/views/field/Status.php
index 35179c4..4e17445 100644
--- a/core/modules/file/lib/Drupal/file/Plugin/views/field/Status.php
+++ b/core/modules/file/lib/Drupal/file/Plugin/views/field/Status.php
@@ -9,6 +9,7 @@
 
 use Drupal\Component\Annotation\PluginID;
 use Drupal\views\Plugin\views\field\FieldPluginBase;
+use Drupal\views\ResultRow;
 
 /**
  * Field handler to translate a node type into its readable form.
@@ -19,7 +20,10 @@
  */
 class Status extends FieldPluginBase {
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     $value = $this->getValue($values);
     return _views_file_status($value);
   }
diff --git a/core/modules/file/lib/Drupal/file/Plugin/views/field/Uri.php b/core/modules/file/lib/Drupal/file/Plugin/views/field/Uri.php
index 1ea01ed..1191265 100644
--- a/core/modules/file/lib/Drupal/file/Plugin/views/field/Uri.php
+++ b/core/modules/file/lib/Drupal/file/Plugin/views/field/Uri.php
@@ -8,6 +8,7 @@
 namespace Drupal\file\Plugin\views\field;
 
 use Drupal\Component\Annotation\PluginID;
+use Drupal\views\ResultRow;
 
 /**
  * Field handler to add rendering file paths as file URLs instead of as internal file URIs.
@@ -32,7 +33,10 @@ public function buildOptionsForm(&$form, &$form_state) {
     parent::buildOptionsForm($form, $form_state);
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     $data = $values->{$this->field_alias};
     if (!empty($this->options['file_download_path']) && $data !== NULL && $data !== '') {
       $data = file_create_url($data);
diff --git a/core/modules/history/lib/Drupal/history/Plugin/views/field/HistoryUserTimestamp.php b/core/modules/history/lib/Drupal/history/Plugin/views/field/HistoryUserTimestamp.php
index c5e56be..62915f4 100644
--- a/core/modules/history/lib/Drupal/history/Plugin/views/field/HistoryUserTimestamp.php
+++ b/core/modules/history/lib/Drupal/history/Plugin/views/field/HistoryUserTimestamp.php
@@ -7,6 +7,7 @@
 
 namespace Drupal\history\Plugin\views\field;
 
+use Drupal\views\ResultRow;
 use Drupal\views\ViewExecutable;
 use Drupal\views\Plugin\views\display\DisplayPluginBase;
 use Drupal\node\Plugin\views\field\Node;
@@ -68,7 +69,10 @@ public function query() {
     parent::query();
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     // Let's default to 'read' state.
     // This code shadows node_mark, but it reads from the db directly and
     // we already have that info.
diff --git a/core/modules/language/lib/Drupal/language/Plugin/views/field/LanguageField.php b/core/modules/language/lib/Drupal/language/Plugin/views/field/LanguageField.php
index d1e9cc0..671efd0 100644
--- a/core/modules/language/lib/Drupal/language/Plugin/views/field/LanguageField.php
+++ b/core/modules/language/lib/Drupal/language/Plugin/views/field/LanguageField.php
@@ -9,6 +9,7 @@
 
 use Drupal\views\Plugin\views\field\FieldPluginBase;
 use Drupal\Component\Annotation\PluginID;
+use Drupal\views\ResultRow;
 
 /**
  * Defines a field handler to translate a language into its readable form.
@@ -36,7 +37,10 @@ public function buildOptionsForm(&$form, &$form_state) {
     );
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     // @todo: Drupal Core dropped native language until config translation is
     // ready, see http://drupal.org/node/1616594.
     $value = $this->getValue($values);
diff --git a/core/modules/node/lib/Drupal/node/Plugin/views/field/Language.php b/core/modules/node/lib/Drupal/node/Plugin/views/field/Language.php
index eb6cb14..1b7be8e 100644
--- a/core/modules/node/lib/Drupal/node/Plugin/views/field/Language.php
+++ b/core/modules/node/lib/Drupal/node/Plugin/views/field/Language.php
@@ -9,6 +9,7 @@
 
 use Drupal\node\Plugin\views\field\Node;
 use Drupal\Component\Annotation\PluginID;
+use Drupal\views\ResultRow;
 
 /**
  * Field handler to translate a language into its readable form.
@@ -36,7 +37,10 @@ public function buildOptionsForm(&$form, &$form_state) {
     );
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     // @todo: Drupal Core dropped native language until config translation is
     // ready, see http://drupal.org/node/1616594.
     $value = $this->getValue($values);
diff --git a/core/modules/node/lib/Drupal/node/Plugin/views/field/Link.php b/core/modules/node/lib/Drupal/node/Plugin/views/field/Link.php
index b19cdcb..a4715a8 100644
--- a/core/modules/node/lib/Drupal/node/Plugin/views/field/Link.php
+++ b/core/modules/node/lib/Drupal/node/Plugin/views/field/Link.php
@@ -46,7 +46,10 @@ public function query() {
     $this->addAdditionalFields();
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     if ($entity = $this->getEntity($values)) {
       return $this->renderLink($entity, $values);
     }
diff --git a/core/modules/node/lib/Drupal/node/Plugin/views/field/Node.php b/core/modules/node/lib/Drupal/node/Plugin/views/field/Node.php
index 7d5a44f..21a254c 100644
--- a/core/modules/node/lib/Drupal/node/Plugin/views/field/Node.php
+++ b/core/modules/node/lib/Drupal/node/Plugin/views/field/Node.php
@@ -87,7 +87,10 @@ protected function renderLink($data, ResultRow $values) {
     return $data;
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     $value = $this->getValue($values);
     return $this->renderLink($this->sanitizeValue($value), $values);
   }
diff --git a/core/modules/node/lib/Drupal/node/Plugin/views/field/Path.php b/core/modules/node/lib/Drupal/node/Plugin/views/field/Path.php
index 78ff114..4c0c6c8 100644
--- a/core/modules/node/lib/Drupal/node/Plugin/views/field/Path.php
+++ b/core/modules/node/lib/Drupal/node/Plugin/views/field/Path.php
@@ -9,6 +9,7 @@
 
 use Drupal\views\Plugin\views\field\FieldPluginBase;
 use Drupal\views\Plugin\views\display\DisplayPluginBase;
+use Drupal\views\ResultRow;
 use Drupal\views\ViewExecutable;
 use Drupal\Component\Annotation\PluginID;
 
@@ -53,7 +54,10 @@ public function query() {
     $this->addAdditionalFields();
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     $nid = $this->getValue($values, 'nid');
     return url("node/$nid", array('absolute' => $this->options['absolute']));
   }
diff --git a/core/modules/node/lib/Drupal/node/Plugin/views/field/Type.php b/core/modules/node/lib/Drupal/node/Plugin/views/field/Type.php
index d712928..1f46301 100644
--- a/core/modules/node/lib/Drupal/node/Plugin/views/field/Type.php
+++ b/core/modules/node/lib/Drupal/node/Plugin/views/field/Type.php
@@ -9,6 +9,7 @@
 
 use Drupal\node\Plugin\views\field\Node;
 use Drupal\Component\Annotation\PluginID;
+use Drupal\views\ResultRow;
 
 /**
  * Field handler to translate a node type into its readable form.
@@ -51,7 +52,10 @@ function render_name($data, $values) {
     return $this->sanitizeValue($data);
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     $value = $this->getValue($values);
     return $this->renderLink($this->render_name($value, $values), $values);
   }
diff --git a/core/modules/search/lib/Drupal/search/Plugin/views/field/Score.php b/core/modules/search/lib/Drupal/search/Plugin/views/field/Score.php
index 9293694..e6646d1 100644
--- a/core/modules/search/lib/Drupal/search/Plugin/views/field/Score.php
+++ b/core/modules/search/lib/Drupal/search/Plugin/views/field/Score.php
@@ -9,6 +9,7 @@
 
 use Drupal\views\Plugin\views\field\Numeric;
 use Drupal\Component\Annotation\PluginID;
+use Drupal\views\ResultRow;
 
 /**
  * Field handler to provide simple renderer that allows linking to a node.
@@ -80,7 +81,10 @@ public function query() {
     }
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     // Only render if we exist.
     if (isset($this->tableAlias)) {
       return parent::render($values);
diff --git a/core/modules/system/lib/Drupal/system/Plugin/views/field/BulkFormBase.php b/core/modules/system/lib/Drupal/system/Plugin/views/field/BulkFormBase.php
index f7c5ea2..87a7516 100644
--- a/core/modules/system/lib/Drupal/system/Plugin/views/field/BulkFormBase.php
+++ b/core/modules/system/lib/Drupal/system/Plugin/views/field/BulkFormBase.php
@@ -10,6 +10,7 @@
 use Drupal\Core\Entity\EntityManager;
 use Drupal\views\Plugin\views\field\FieldPluginBase;
 use Drupal\views\Plugin\views\style\Table;
+use Drupal\views\ResultRow;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 
 /**
@@ -50,9 +51,9 @@ public static function create(ContainerInterface $container, array $configuratio
   }
 
   /**
-   * Overrides \Drupal\views\Plugin\views\Plugin\field\FieldPluginBase::render().
+   * {@inheritdoc}
    */
-  public function render($values) {
+  public function render(ResultRow $values) {
     return '<!--form-item-' . $this->options['id'] . '--' . $this->view->row_index . '-->';
   }
 
diff --git a/core/modules/taxonomy/lib/Drupal/taxonomy/Plugin/views/field/Language.php b/core/modules/taxonomy/lib/Drupal/taxonomy/Plugin/views/field/Language.php
index b289903..b2d4e33 100644
--- a/core/modules/taxonomy/lib/Drupal/taxonomy/Plugin/views/field/Language.php
+++ b/core/modules/taxonomy/lib/Drupal/taxonomy/Plugin/views/field/Language.php
@@ -8,6 +8,7 @@
 namespace Drupal\taxonomy\Plugin\views\field;
 
 use Drupal\Component\Annotation\PluginID;
+use Drupal\views\ResultRow;
 
 /**
  * Field handler to show the language of a taxonomy term.
@@ -17,9 +18,9 @@
 class Language extends Taxonomy {
 
   /**
-   * Overrides Drupal\taxonomy\Plugin\views\field\Taxonomy::render().
+   * {@inheritdoc}
    */
-  public function render($values) {
+  public function render(ResultRow $values) {
     $value = $this->getValue($values);
     $language = language_load($value);
     $value = $language ? $language->name : '';
diff --git a/core/modules/taxonomy/lib/Drupal/taxonomy/Plugin/views/field/LinkEdit.php b/core/modules/taxonomy/lib/Drupal/taxonomy/Plugin/views/field/LinkEdit.php
index 00d6c71..54b5ad5 100644
--- a/core/modules/taxonomy/lib/Drupal/taxonomy/Plugin/views/field/LinkEdit.php
+++ b/core/modules/taxonomy/lib/Drupal/taxonomy/Plugin/views/field/LinkEdit.php
@@ -9,6 +9,7 @@
 
 use Drupal\views\Plugin\views\field\FieldPluginBase;
 use Drupal\views\Plugin\views\display\DisplayPluginBase;
+use Drupal\views\ResultRow;
 use Drupal\views\ViewExecutable;
 use Drupal\Component\Annotation\PluginID;
 
@@ -53,7 +54,10 @@ public function query() {
     $this->addAdditionalFields();
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     // Check there is an actual value, as on a relationship there may not be.
     if ($tid = $this->getValue($values, 'tid')) {
       // Mock a term object for taxonomy_term_access(). Use machine name and
diff --git a/core/modules/taxonomy/lib/Drupal/taxonomy/Plugin/views/field/Taxonomy.php b/core/modules/taxonomy/lib/Drupal/taxonomy/Plugin/views/field/Taxonomy.php
index f47368d..b2ff458 100644
--- a/core/modules/taxonomy/lib/Drupal/taxonomy/Plugin/views/field/Taxonomy.php
+++ b/core/modules/taxonomy/lib/Drupal/taxonomy/Plugin/views/field/Taxonomy.php
@@ -7,6 +7,7 @@
 
 namespace Drupal\taxonomy\Plugin\views\field;
 
+use Drupal\views\Plugin\views\area\Result;
 use Drupal\views\Plugin\views\field\FieldPluginBase;
 use Drupal\views\Plugin\views\display\DisplayPluginBase;
 use Drupal\views\ResultRow;
@@ -88,7 +89,10 @@ protected function renderLink($data, ResultRow $values) {
     return $data;
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     $value = $this->getValue($values);
     return $this->renderLink($this->sanitizeValue($value), $values);
   }
diff --git a/core/modules/user/lib/Drupal/user/Plugin/views/field/Language.php b/core/modules/user/lib/Drupal/user/Plugin/views/field/Language.php
index 0d40280..8ca779d 100644
--- a/core/modules/user/lib/Drupal/user/Plugin/views/field/Language.php
+++ b/core/modules/user/lib/Drupal/user/Plugin/views/field/Language.php
@@ -39,7 +39,10 @@ protected function renderLink($data, ResultRow $values) {
     return $this->sanitizeValue($lang->name);
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     $value = $this->getValue($values);
     return $this->renderLink($this->sanitizeValue($value), $values);
   }
diff --git a/core/modules/user/lib/Drupal/user/Plugin/views/field/Link.php b/core/modules/user/lib/Drupal/user/Plugin/views/field/Link.php
index 4b8c3a3..390bfc4 100644
--- a/core/modules/user/lib/Drupal/user/Plugin/views/field/Link.php
+++ b/core/modules/user/lib/Drupal/user/Plugin/views/field/Link.php
@@ -58,9 +58,9 @@ public function query() {
   }
 
   /**
-   * Overrides \Drupal\views\Plugin\views\field\FieldPluginBase::render().
+   * {@inheritdoc}
    */
-  public function render($values) {
+  public function render(ResultRow $values) {
     return $this->renderLink($this->getEntity($values), $values);
   }
 
diff --git a/core/modules/user/lib/Drupal/user/Plugin/views/field/User.php b/core/modules/user/lib/Drupal/user/Plugin/views/field/User.php
index 4e887cc..bb7e861 100644
--- a/core/modules/user/lib/Drupal/user/Plugin/views/field/User.php
+++ b/core/modules/user/lib/Drupal/user/Plugin/views/field/User.php
@@ -61,7 +61,10 @@ protected function renderLink($data, ResultRow $values) {
     return $data;
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     $value = $this->getValue($values);
     return $this->renderLink($this->sanitizeValue($value), $values);
   }
diff --git a/core/modules/user/lib/Drupal/user/Plugin/views/field/UserData.php b/core/modules/user/lib/Drupal/user/Plugin/views/field/UserData.php
index f0074fa..fda613a 100644
--- a/core/modules/user/lib/Drupal/user/Plugin/views/field/UserData.php
+++ b/core/modules/user/lib/Drupal/user/Plugin/views/field/UserData.php
@@ -9,6 +9,7 @@
 
 use Drupal\views\Plugin\views\display\DisplayPluginBase;
 use Drupal\views\Plugin\views\field\FieldPluginBase;
+use Drupal\views\ResultRow;
 use Drupal\views\ViewExecutable;
 use Drupal\user\UserDataInterface;
 use Drupal\Component\Annotation\PluginID;
@@ -75,9 +76,9 @@ public function buildOptionsForm(&$form, &$form_state) {
   }
 
   /**
-   * Overrides \Drupal\views\Plugin\views\field\FieldPluginBase::render().
+   * {@inheritdoc}
    */
-  public function render($values) {
+  public function render(ResultRow $values) {
     $uid = $this->getValue($values);
     $data = $this->userData->get($this->options['data_module'], $uid, $this->options['data_name']);
 
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/field/Boolean.php b/core/modules/views/lib/Drupal/views/Plugin/views/field/Boolean.php
index 6f586af..2f94593 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/field/Boolean.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/field/Boolean.php
@@ -7,6 +7,7 @@
 
 namespace Drupal\views\Plugin\views\field;
 
+use Drupal\views\ResultRow;
 use Drupal\views\ViewExecutable;
 use Drupal\views\Plugin\views\display\DisplayPluginBase;
 use Drupal\Component\Annotation\PluginID;
@@ -100,7 +101,10 @@ public function buildOptionsForm(&$form, &$form_state) {
     parent::buildOptionsForm($form, $form_state);
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     $value = $this->getValue($values);
     if (!empty($this->options['not'])) {
       $value = !$value;
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/field/Custom.php b/core/modules/views/lib/Drupal/views/Plugin/views/field/Custom.php
index b1ce7ae..d1a9dd6 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/field/Custom.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/field/Custom.php
@@ -8,6 +8,7 @@
 namespace Drupal\views\Plugin\views\field;
 
 use Drupal\Component\Annotation\PluginID;
+use Drupal\views\ResultRow;
 
 /**
  * A handler to provide a field that is completely custom by the administrator.
@@ -41,7 +42,10 @@ public function buildOptionsForm(&$form, &$form_state) {
     $form['#pre_render'][] = array($this, 'preRenderCustomForm');
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     // Return the text, so the code never thinks the value is empty.
     return $this->options['alter']['text'];
   }
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/field/Date.php b/core/modules/views/lib/Drupal/views/Plugin/views/field/Date.php
index 654e27a..c4d94cc 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/field/Date.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/field/Date.php
@@ -9,6 +9,7 @@
 
 use Drupal\Component\Annotation\PluginID;
 use Drupal\Core\Entity\EntityStorageControllerInterface;
+use Drupal\views\ResultRow;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 use Drupal\Core\Datetime\Date as DateService;
 
@@ -129,7 +130,10 @@ public function buildOptionsForm(&$form, &$form_state) {
     parent::buildOptionsForm($form, $form_state);
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     $value = $this->getValue($values);
     $format = $this->options['date_format'];
     if (in_array($format, array('custom', 'raw time ago', 'time ago', 'raw time hence', 'time hence', 'raw time span', 'time span', 'raw time span', 'inverse time span', 'time span'))) {
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/field/Dropbutton.php b/core/modules/views/lib/Drupal/views/Plugin/views/field/Dropbutton.php
index 491463d..ab736b6 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/field/Dropbutton.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/field/Dropbutton.php
@@ -8,6 +8,7 @@
 namespace Drupal\views\Plugin\views\field;
 
 use Drupal\Component\Annotation\PluginID;
+use Drupal\views\ResultRow;
 
 /**
  * Provides a handler that renders links as dropbutton.
@@ -19,9 +20,9 @@
 class Dropbutton extends Links {
 
   /**
-   * Render the dropdown button.
+   * {@inheritdoc}
    */
-  public function render($values) {
+  public function render(ResultRow $values) {
     $links = $this->getLinks();
 
     if (!empty($links)) {
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/field/EntityLabel.php b/core/modules/views/lib/Drupal/views/Plugin/views/field/EntityLabel.php
index 7ecf18e..de98e5b 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/field/EntityLabel.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/field/EntityLabel.php
@@ -9,6 +9,7 @@
 
 use Drupal\Component\Annotation\PluginID;
 use Drupal\views\Plugin\views\field\FieldPluginBase;
+use Drupal\views\ResultRow;
 use Drupal\views\ViewExecutable;
 use Drupal\views\Plugin\views\display\DisplayPluginBase;
 use Drupal\Core\Entity\EntityManager;
@@ -98,7 +99,7 @@ public function buildOptionsForm(&$form, &$form_state) {
   /**
    * {@inheritdoc}
    */
-  public function render($values) {
+  public function render(ResultRow $values) {
     $entity = $this->loadedReferencers[$this->getValue($values, $this->definition['entity type field'])][$this->getValue($values)];
 
     if (empty($entity)) {
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/field/FileSize.php b/core/modules/views/lib/Drupal/views/Plugin/views/field/FileSize.php
index bcf2e71..98efde4 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/field/FileSize.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/field/FileSize.php
@@ -8,6 +8,7 @@
 namespace Drupal\views\Plugin\views\field;
 
 use Drupal\Component\Annotation\PluginID;
+use Drupal\views\ResultRow;
 
 /**
  * Render a numeric value as a size.
@@ -38,7 +39,10 @@ public function buildOptionsForm(&$form, &$form_state) {
     );
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     $value = $this->getValue($values);
     if ($value) {
       switch ($this->options['file_size_display']) {
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/field/MachineName.php b/core/modules/views/lib/Drupal/views/Plugin/views/field/MachineName.php
index f90b1a9..3ac6239 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/field/MachineName.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/field/MachineName.php
@@ -8,6 +8,7 @@
 namespace Drupal\views\Plugin\views\field;
 
 use Drupal\Component\Annotation\PluginID;
+use Drupal\views\ResultRow;
 
 /**
  * Field handler whichs allows to show machine name content as human name.
@@ -66,7 +67,10 @@ public function preRender(&$values) {
     $this->getValueOptions();
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     $value = $values->{$this->field_alias};
     if (!empty($this->options['machine_name']) || !isset($this->value_options[$value])) {
       $result = check_plain($value);
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/field/Markup.php b/core/modules/views/lib/Drupal/views/Plugin/views/field/Markup.php
index 24c98c1..8145321 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/field/Markup.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/field/Markup.php
@@ -9,6 +9,7 @@
 
 use Drupal\Component\Annotation\PluginID;
 use Drupal\views\Plugin\views\display\DisplayPluginBase;
+use Drupal\views\ResultRow;
 use Drupal\views\ViewExecutable;
 
 /**
@@ -40,7 +41,10 @@ public function init(ViewExecutable $view, DisplayPluginBase $display, array &$o
     }
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     $value = $this->getValue($values);
     if (is_array($this->format)) {
       $format = $this->getValue($values, 'format');
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/field/Numeric.php b/core/modules/views/lib/Drupal/views/Plugin/views/field/Numeric.php
index 0ab6c6f..11a4a23 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/field/Numeric.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/field/Numeric.php
@@ -8,6 +8,7 @@
 namespace Drupal\views\Plugin\views\field;
 
 use Drupal\Component\Annotation\PluginID;
+use Drupal\views\ResultRow;
 
 /**
  * Render a field as a numeric value
@@ -124,7 +125,10 @@ public function buildOptionsForm(&$form, &$form_state) {
     parent::buildOptionsForm($form, $form_state);
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     $value = $this->getValue($values);
     if (!empty($this->options['set_precision'])) {
       $value = number_format($value, $this->options['precision'], $this->options['decimal'], $this->options['separator']);
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/field/Serialized.php b/core/modules/views/lib/Drupal/views/Plugin/views/field/Serialized.php
index 2aa8639..2ec3756 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/field/Serialized.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/field/Serialized.php
@@ -8,6 +8,7 @@
 namespace Drupal\views\Plugin\views\field;
 
 use Drupal\Component\Annotation\PluginID;
+use Drupal\views\ResultRow;
 
 /**
  * Field handler to show data of serialized fields.
@@ -59,7 +60,10 @@ public function validateOptionsForm(&$form, &$form_state) {
     }
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     $value = $values->{$this->field_alias};
 
     if ($this->options['format'] == 'unserialized') {
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/field/TimeInterval.php b/core/modules/views/lib/Drupal/views/Plugin/views/field/TimeInterval.php
index a42de6f..bbd1a96 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/field/TimeInterval.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/field/TimeInterval.php
@@ -8,6 +8,7 @@
 namespace Drupal\views\Plugin\views\field;
 
 use Drupal\Component\Annotation\PluginID;
+use Drupal\views\ResultRow;
 
 /**
  * A handler to provide proper displays for time intervals.
@@ -37,7 +38,10 @@ public function buildOptionsForm(&$form, &$form_state) {
     );
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     $value = $values->{$this->field_alias};
     return format_interval($value, isset($this->options['granularity']) ? $this->options['granularity'] : 2);
   }
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/field/Url.php b/core/modules/views/lib/Drupal/views/Plugin/views/field/Url.php
index 9b72709..5095f8d 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/field/Url.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/field/Url.php
@@ -8,6 +8,7 @@
 namespace Drupal\views\Plugin\views\field;
 
 use Drupal\Component\Annotation\PluginID;
+use Drupal\views\ResultRow;
 
 /**
  * Field handler to provide simple renderer that turns a URL into a clickable link.
@@ -38,7 +39,10 @@ public function buildOptionsForm(&$form, &$form_state) {
     parent::buildOptionsForm($form, $form_state);
   }
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     $value = $this->getValue($values);
     if (!empty($this->options['display_as_link'])) {
       return l($this->sanitizeValue($value), $value, array('html' => TRUE));
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/field/Xss.php b/core/modules/views/lib/Drupal/views/Plugin/views/field/Xss.php
index 9f1aa5e..6592442 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/field/Xss.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/field/Xss.php
@@ -9,6 +9,7 @@
 
 use Drupal\views\Plugin\views\field\FieldPluginBase;
 use Drupal\Component\Annotation\PluginID;
+use Drupal\views\ResultRow;
 
 /**
  * A handler to run a field through simple XSS filtering.
@@ -19,7 +20,10 @@
  */
 class Xss extends FieldPluginBase {
 
-  public function render($values) {
+  /**
+   * {@inheritdoc}
+   */
+  public function render(ResultRow $values) {
     $value = $this->getValue($values);
     return $this->sanitizeValue($value, 'xss');
   }
diff --git a/core/modules/views/tests/modules/views_test_data/lib/Drupal/views_test_data/Plugin/views/field/FieldTest.php b/core/modules/views/tests/modules/views_test_data/lib/Drupal/views_test_data/Plugin/views/field/FieldTest.php
index fcee561..8edf006 100644
--- a/core/modules/views/tests/modules/views_test_data/lib/Drupal/views_test_data/Plugin/views/field/FieldTest.php
+++ b/core/modules/views/tests/modules/views_test_data/lib/Drupal/views_test_data/Plugin/views/field/FieldTest.php
@@ -9,6 +9,7 @@
 
 use Drupal\Component\Annotation\PluginID;
 use Drupal\views\Plugin\views\field\FieldPluginBase;
+use Drupal\views\ResultRow;
 
 /**
  * @PluginID("test_field")
@@ -50,9 +51,9 @@ protected function addSelfTokens(&$tokens, $item) {
   }
 
   /**
-   * Overrides Drupal\views\Plugin\views\field\FieldPluginBase::render().
+   * {@inheritdoc}
    */
-  public function render($values) {
+  public function render(ResultRow $values) {
     return $this->sanitizeValue($this->getTestValue());
   }
 

diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/field/FieldPluginBase.php b/core/modules/views/lib/Drupal/views/Plugin/views/field/FieldPluginBase.php
index 30f7167..540d608 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/field/FieldPluginBase.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/field/FieldPluginBase.php
@@ -1087,18 +1087,18 @@ public function adminSummary() {
    * This gives the handlers some time to set up before any handler has
    * been rendered.
    *
    * @param $values
    *   An array of all objects returned from the query.
    */
   public function preRender(&$values) { }
 
   /**
-   * Render the field.
+   * Renders the field.
    *
-   * @param $values
+   * @param \Drupal\views\ResultRow $values
    *   The values retrieved from the database.
    */
-  public function render($values) {
+  public function render(ResultRow $values) {
     $value = $this->getValue($values);
     return $this->sanitizeValue($value);
   }
@@ -1108,8 +1108,11 @@ public function render($values) {
    *
    * This renders a field normally, then decides if render-as-link and
    * text-replacement rendering is necessary.
+   *
+   * @param \Drupal\views\ResultRow $values
+   *   The values retrieved from the database.
    */
-  public function advancedRender($values) {
+  public function advancedRender(ResultRow $values) {
     if ($this->allowAdvancedRender() && method_exists($this, 'render_item')) {
       $raw_items = $this->getItems($values);
       // If there are no items, set the original value to NULL.
@@ -1087,18 +1087,18 @@ public function adminSummary() {
    * been rendered.
    *
-   * @param $values
-   *   An array of all objects returned from the query.
+   * @param array $values
+   *   An array of all \Drupal\views\ResultRow objects returned from the query.
    */
   public function preRender(&$values) { }